package App::DPath;
# git description: v0.09-2-ge22ecd9

our $AUTHORITY = 'cpan:SCHWIGON';
# ABSTRACT: Cmdline tool around Data::DPath
$App::DPath::VERSION = '0.10';
use 5.008; # Data::DPath requires it

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

App::DPath - Cmdline tool around Data::DPath

=head1 ABOUT

See L<dpath|dpath>.

=head1 AUTHOR

Steffen Schwigon <ss5@renormalist.net>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Steffen Schwigon.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
